Module: ELFTools::Constants::PN

Extended by:
Naming
Included in:
ELFTools::Constants
Defined in:
lib/elftools/constants.rb

Overview

The escape value the ELF header records where it cannot hold a count of the program headers, which is then recorded in the first section header.

Constant Summary collapse

PN_XNUM =

the number of program headers is too large for the header to hold

0xffff

Constants included from Naming

Naming::ARCHITECTURES

Method Summary

Methods included from Naming

mapping