Module: ELFTools::Constants::PN
Overview
The escape value the ELF header records where it cannot hold a count of the program headers, which is then recorded in the first section header.
Constant Summary collapse
- PN_XNUM =
the number of program headers is too large for the header to hold
0xffff