Module: ELFTools::Constants::VER_FLG
- Included in:
- ELFTools::Constants
- Defined in:
- lib/elftools/constants.rb
Overview
Flags of a version, recorded in the vd_flags of a definition and the
vna_flags of a requirement.
Constant Summary collapse
- VER_FLG_BASE =
The version the file itself is, rather than one of the versions it defines
0x1- VER_FLG_WEAK =
A version no symbol is bound to
0x2- VER_FLG_INFO =
A version recorded for information rather than to be matched
0x4