Class: ELFTools::Sections::VersionDefinitionSection
- Defined in:
- lib/elftools/sections/version_definition_section.rb
Overview
Class of the section recording the versions a file defines for what it exports.
This section is usually named .gnu.version_d, and records the very
versions the DT_VERDEF tag points at.
Instance Attribute Summary
Attributes inherited from Section
Instance Method Summary collapse
-
#definitions ⇒ Array<ELFTools::VersionTables::Definition>
The versions this file defines for what it exports.
-
#initialize(header, stream, section_at: nil, **_kwargs) ⇒ VersionDefinitionSection
constructor
Instantiate a VersionDefinitionSection object.
Methods inherited from Section
#allocated?, create, #data, #executable?, #name, #null?, #type, #writable?
Constructor Details
#initialize(header, stream, section_at: nil, **_kwargs) ⇒ VersionDefinitionSection
Instantiate a ELFTools::Sections::VersionDefinitionSection object.
22 23 24 25 |
# File 'lib/elftools/sections/version_definition_section.rb', line 22 def initialize(header, stream, section_at: nil, **_kwargs) @section_at = section_at super end |
Instance Method Details
#definitions ⇒ Array<ELFTools::VersionTables::Definition>
The versions this file defines for what it exports.
33 34 35 36 37 |
# File 'lib/elftools/sections/version_definition_section.rb', line 33 def definitions @definitions ||= VersionTables.new(stream, @section_at.call(header.sh_link), endian: header.class.self_endian) .definitions(header.sh_offset.to_i, header.sh_info.to_i) end |