Module: ELFTools::Util
- Extended by:
- ClassMethods
- Defined in:
- lib/elftools/util.rb
Overview
Define some util methods.
Defined Under Namespace
Modules: ClassMethods
Constant Summary collapse
- CSTRING_CHUNK =
How many bytes ELFTools::Util::ClassMethods#cstring takes from a stream at a time. Long enough that a name is usually read in one, short enough that reading one never reaches far past its end.
64