Class: ELFTools::VersionTables::Definition
- Inherits:
-
Object
- Object
- ELFTools::VersionTables::Definition
- Defined in:
- lib/elftools/version_tables.rb
Overview
A version a file defines for what it exports.
Instance Attribute Summary collapse
-
#index ⇒ Integer
readonly
The index the symbols name it with.
-
#name ⇒ String
readonly
The name.
-
#parents ⇒ Array<String>
readonly
The names of the versions it descends from.
Instance Method Summary collapse
-
#base? ⇒ Boolean
Whether this names the file itself rather than a version of it, which the first definition of a file does.
-
#initialize(name, index, parents, base: false) ⇒ Definition
constructor
Instantiate a Definition object.
Constructor Details
#initialize(name, index, parents, base: false) ⇒ Definition
Instantiate a ELFTools::VersionTables::Definition object.
140 141 142 143 144 145 |
# File 'lib/elftools/version_tables.rb', line 140 def initialize(name, index, parents, base: false) @name = name @index = index @parents = parents @base = base end |
Instance Attribute Details
#index ⇒ Integer (readonly)
Returns The index the symbols name it with.
132 133 134 |
# File 'lib/elftools/version_tables.rb', line 132 def index @index end |
#name ⇒ String (readonly)
Returns The name.
131 132 133 |
# File 'lib/elftools/version_tables.rb', line 131 def name @name end |
#parents ⇒ Array<String> (readonly)
Returns The names of the versions it descends from.
133 134 135 |
# File 'lib/elftools/version_tables.rb', line 133 def parents @parents end |
Instance Method Details
#base? ⇒ Boolean
Whether this names the file itself rather than a version of it, which the first definition of a file does.
150 151 152 |
# File 'lib/elftools/version_tables.rb', line 150 def base? @base end |